diff -wurpN nagios-3-clean/base/events.c nagios-3-modified/base/events.c
--- nagios-3-clean/base/events.c	2009-06-16 21:23:38.000000000 -0600
+++ nagios-3-modified/base/events.c	2009-06-17 20:48:10.000000000 -0600
@@ -31,6 +31,9 @@
 #include "../include/broker.h"
 #include "../include/sretention.h"
 
+#ifdef EVENT_PROFILER
+#include "../include/profiler.h"
+#endif
 
 extern char	*config_file;
 
@@ -930,6 +933,9 @@ int event_execution_loop(void){
 	struct timespec delay;
 	pid_t wait_result;
 
+#ifdef EVENT_PROFILER
+	struct timeval start;
+#endif
 
 	log_debug_info(DEBUGL_FUNCTIONS,0,"event_execution_loop() start\n");
 
@@ -948,7 +954,11 @@ int event_execution_loop(void){
 	sleep_event.next=NULL;
 	sleep_event.prev=NULL;
 
-	while(1){
+	while(1)
+{
+#ifdef EVENT_PROFILER
+        gettimeofday(&start,NULL);
+#endif
 
 		/* see if we should exit or restart (a signal was encountered) */
 		if(sigshutdown==TRUE || sigrestart==TRUE)
@@ -1201,6 +1211,11 @@ int event_execution_loop(void){
 			last_status_update=current_time;
 			update_program_status(FALSE);
 			}
+
+#ifdef EVENT_PROFILER
+            profiler_update(EVENT_LOOP_COMPLETION, start);
+#endif
+
 	        }
 
 	log_debug_info(DEBUGL_FUNCTIONS,0,"event_execution_loop() end\n");
@@ -1217,7 +1232,10 @@ int handle_timed_event(timed_event *even
 	void (*userfunc)(void *);
 	struct timeval tv;
 	double latency=0.0;
-
+#ifdef EVENT_PROFILER
+    struct timeval start;
+    gettimeofday(&start,NULL);
+#endif
 
 	log_debug_info(DEBUGL_FUNCTIONS,0,"handle_timed_event() start\n");
 
@@ -1411,7 +1429,9 @@ int handle_timed_event(timed_event *even
 	        }
 
 	log_debug_info(DEBUGL_FUNCTIONS,0,"handle_timed_event() end\n");
-
+#ifdef EVENT_PROFILER
+    profiler_update(event->event_type,start);
+#endif
 	return OK;
         }
 
diff -wurpN nagios-3-clean/base/Makefile.in nagios-3-modified/base/Makefile.in
--- nagios-3-clean/base/Makefile.in	2009-06-16 21:57:21.000000000 -0600
+++ nagios-3-modified/base/Makefile.in	2009-06-17 21:16:01.000000000 -0600
@@ -122,7 +122,7 @@ DDATAHDRS=
 DDATADEPS=$(DDATALIBS)
 
 
-OBJS=$(BROKER_O) checks.o config.o commands.o events.o flapping.o logging.o macros-base.o netutils.o notifications.o sehandlers.o skiplist.o utils.o $(RDATALIBS) $(CDATALIBS) $(ODATALIBS) $(SDATALIBS) $(PDATALIBS) $(DDATALIBS) $(BASEEXTRALIBS) $(SNPRINTF_O) $(PERLXSI_O)
+OBJS=$(BROKER_O) checks.o config.o commands.o events.o flapping.o logging.o macros-base.o netutils.o notifications.o sehandlers.o skiplist.o utils.o profiler.o $(RDATALIBS) $(CDATALIBS) $(ODATALIBS) $(SDATALIBS) $(PDATALIBS) $(DDATALIBS) $(BASEEXTRALIBS) $(SNPRINTF_O) $(PERLXSI_O)
 OBJDEPS=$(ODATADEPS) $(ODATADEPS) $(RDATADEPS) $(CDATADEPS) $(SDATADEPS) $(PDATADEPS) $(DDATADEPS) $(BROKER_H)
 
 all: nagios nagiostats
@@ -180,7 +180,7 @@ nagios: nagios.c $(OBJS) $(OBJDEPS) $(SR
 	$(CC) $(CFLAGS) -o $@ nagios.c $(OBJS) $(BROKER_LDFLAGS) $(LDFLAGS) $(PERLLIBS) $(MATHLIBS) $(SOCKETLIBS) $(THREADLIBS) $(BROKERLIBS) $(LIBS)
 
 nagiostats: nagiostats.c $(SRC_INCLUDE)/locations.h
-	$(CC) $(CFLAGS) -o $@ nagiostats.c $(LDFLAGS) $(MATHLIBS) $(LIBS)
+	$(CC) $(CFLAGS) -o $@ statsprofiler.c nagiostats.c $(LDFLAGS) $(MATHLIBS) $(LIBS)
 
 $(OBJS): $(SRC_INCLUDE)/locations.h
 
diff -wurpN nagios-3-clean/base/nagios.c nagios-3-modified/base/nagios.c
--- nagios-3-clean/base/nagios.c	2009-06-17 08:11:17.000000000 -0600
+++ nagios-3-modified/base/nagios.c	2009-06-17 20:57:14.000000000 -0600
@@ -48,6 +48,9 @@
 #include "../include/broker.h"
 #include "../include/nebmods.h"
 #include "../include/nebmodules.h"
+#ifdef EVENT_PROFILER
+#include "../include/profiler.h"
+#endif
 
 /*#define DEBUG_MEMORY 1*/
 #ifdef DEBUG_MEMORY
@@ -381,6 +384,9 @@ int main(int argc, char **argv){
 #ifdef DEBUG_MEMORY
 	mtrace();
 #endif
+#ifdef EVENT_PROFILER
+    profiler_init();
+#endif
 
 	if(daemon_mode==FALSE){
 		printf("\nNagios %s\n",PROGRAM_VERSION);
diff -wurpN nagios-3-clean/base/nagiostats.c nagios-3-modified/base/nagiostats.c
--- nagios-3-clean/base/nagiostats.c	2009-05-14 17:52:42.000000000 -0600
+++ nagios-3-modified/base/nagiostats.c	2009-06-17 21:18:06.000000000 -0600
@@ -31,12 +31,19 @@
 #include "../include/nagios.h"
 #include "../include/locations.h"
 
+#ifdef EVENT_PROFILER
+#include "../include/statsprofiler.h"
+#endif
+
 #define STATUS_NO_DATA             0
 #define STATUS_INFO_DATA           1
 #define STATUS_PROGRAM_DATA        2
 #define STATUS_HOST_DATA           3
 #define STATUS_SERVICE_DATA        4
 
+#ifdef EVENT_PROFILER
+profile_object* profiled_data = NULL;
+#endif
 
 char *main_config_file=NULL;
 char *status_file=NULL;
@@ -390,6 +397,30 @@ int main(int argc, char **argv){
 		printf(" NUMPSVSVCCHECKSxM    number of passive service checks occuring in last 1/5/15 minutes.\n");
 		printf(" NUMEXTCMDSxM         number of external commands processed in last 1/5/15 minutes.\n");
 
+#ifdef EVENT_PROFILER
+        /* read main config file */
+        result=read_config_file();
+        if(result==ERROR && mrtg_mode==FALSE)
+        {
+            printf("Error processing config file '%s'\n",main_config_file);
+            return ERROR;
+        }
+
+        /* read the status file */
+        result=read_status_file();
+        if(result==ERROR && mrtg_mode==FALSE)
+        {
+            printf("Error reading status file '%s'\n",status_file);
+            return ERROR;
+        }
+
+        profile_object* p = profiled_data;
+        while(p)
+        {
+            printf("PROFILE_(COUNTER/ELAPSED/EVENTPS)_%s\t\tdynamically generated profile data.\n",p->name);
+            p = p->next;
+        }
+#endif
 		printf("\n");
 		printf(" Note: Replace x's in MRTG variable names with 'MIN', 'MAX', 'AVG', or the\n");
 		printf("       the appropriate number (i.e. '1', '5', '15', or '60').\n");
@@ -759,6 +790,10 @@ int display_mrtg_values(void){
 		else if(!strcmp(temp_ptr,"NUMHSTDOWNTIME"))
 			printf("%d%s",hosts_in_downtime,mrtg_delimiter);
 
+#ifdef EVENT_PROFILER
+        else if(strstr(temp_ptr,"PROFILE_"))
+            profile_data_output_mrtg(temp_ptr+strlen("PROFILE_"),mrtg_delimiter);
+#endif
 		else
 			printf("%s%s",temp_ptr,mrtg_delimiter);
 	        }
@@ -847,6 +882,13 @@ int display_stats(void){
 	printf("\n");
 	printf("\n");
 
+#ifdef EVENT_PROFILER
+	printf("\n\nEVENT PROFILE DATA:\t\ttotal seconds spent / number of events / avg time per event / events per second \n");
+	printf("----------------------------------------------------\n");
+
+    profile_data_print();
+#endif
+
 
 	/*
 	printf("CURRENT COMMENT DATA\n");
@@ -1316,6 +1358,16 @@ int read_status_file(void){
 					if((temp_ptr=strtok(NULL,",")))
 						serial_host_checks_last_15min=atoi(temp_ptr);
 					}
+#ifdef EVENT_PROFILER
+                else if(strstr(var,"PROFILE_") && !strstr(var,"null"))
+                {
+                    if(strstr(var,"COUNTER"))
+                        profile_object_update_count(var+strlen("PROFILE_COUNTER_"),strtod(val,NULL));
+
+                    if(strstr(var,"ELAPSED"))
+                        profile_object_update_elapsed(var+strlen("PROFILE_ELAPSED_"),atoi(val));
+                }
+#endif
 				break;
 
 			case STATUS_HOST_DATA:
diff -wurpN nagios-3-clean/base/profiler.c nagios-3-modified/base/profiler.c
--- nagios-3-clean/base/profiler.c	1969-12-31 17:00:00.000000000 -0700
+++ nagios-3-modified/base/profiler.c	2009-06-17 21:23:42.000000000 -0600
@@ -0,0 +1,214 @@
+/*****************************************************************************
+ *
+ * PROFILER.C - Event Profiler For Nagios
+ *
+ * Program: Nagios
+ * Version: 2.12
+ * License: GPL
+ * Copyright: (c) 2009 Intellectual Reserve Inc.
+ * Author:  Steven D. Morrey (nagios-devel@lists.sourceforge.net
+ *
+ * First Written:   06-09-2009 (start of development)
+ * Last Modified:   06-09-2009
+ *
+ * Description:
+ *
+ * Nagios is a network monitoring tool that will check hosts and services
+ * that you specify.  This utility adds the ability to profile the events
+ * occuring within the application itself
+ *
+ * License:
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *****************************************************************************/
+#ifdef EVENT_PROFILER
+#include "../include/nagios.h"
+#include "../include/profiler.h"
+
+int profiler_item_count = -1;
+
+int profiler_core_event_types[] = {
+        EVENT_SERVICE_CHECK,
+        EVENT_HOST_CHECK,
+        EVENT_COMMAND_CHECK,
+        EVENT_LOG_ROTATION,
+        EVENT_PROGRAM_SHUTDOWN,
+        EVENT_PROGRAM_RESTART,
+        EVENT_CHECK_REAPER,
+        EVENT_ORPHAN_CHECK,
+        EVENT_RETENTION_SAVE,
+        EVENT_STATUS_SAVE,
+        EVENT_SCHEDULED_DOWNTIME,
+        EVENT_SFRESHNESS_CHECK,
+        EVENT_HFRESHNESS_CHECK,
+        EVENT_EXPIRE_DOWNTIME,
+        EVENT_RESCHEDULE_CHECKS,
+        EVENT_EXPIRE_COMMENT,
+        EVENT_USER_FUNCTION,
+        EVENT_LOOP_COMPLETION,
+	EVENT_CHECK_PROGRAM_UPDATE
+};
+
+profiler_item * profiler;
+
+
+void profiler_init()
+{
+    profiler = (profiler_item*)calloc(++profiler_item_count,sizeof(profiler_item));
+    profiler_add(EVENT_SERVICE_CHECK,"EVENT_SERVICE_CHECK");
+    profiler_add(EVENT_HOST_CHECK,"EVENT_HOST_CHECK");
+    profiler_add(EVENT_COMMAND_CHECK,"EVENT_COMMAND_CHECK");
+    profiler_add(EVENT_LOG_ROTATION,"EVENT_LOG_ROTATION");
+    profiler_add(EVENT_PROGRAM_SHUTDOWN,"EVENT_PROGRAM_SHUTDOWN");
+    profiler_add(EVENT_PROGRAM_RESTART,"EVENT_PROGRAM_RESTART");
+    profiler_add(EVENT_CHECK_REAPER,"EVENT_CHECK_REAPER");
+    profiler_add(EVENT_ORPHAN_CHECK,"EVENT_ORPHAN_CHECK");
+    profiler_add(EVENT_RETENTION_SAVE,"EVENT_RETENTION_SAVE");
+    profiler_add(EVENT_STATUS_SAVE,"EVENT_STATUS_SAVE");
+	profiler_add(EVENT_CHECK_PROGRAM_UPDATE,"EVENT_CHECK_PROGRAM_UPDATE");
+    profiler_add(EVENT_SCHEDULED_DOWNTIME,"EVENT_SCHEDULED_DOWNTIME");
+    profiler_add(EVENT_SFRESHNESS_CHECK,"EVENT_SFRESHNESS_CHECK");
+    profiler_add(EVENT_HFRESHNESS_CHECK,"EVENT_HFRESHNESS_CHECK");
+    profiler_add(EVENT_EXPIRE_DOWNTIME,"EVENT_EXPIRE_DOWNTIME");
+    profiler_add(EVENT_RESCHEDULE_CHECKS,"EVENT_RESCHEDULE_CHECKS");
+    profiler_add(EVENT_EXPIRE_COMMENT,"EVENT_EXPIRE_COMMENT");
+    profiler_add(EVENT_USER_FUNCTION,"EVENT_USER_FUNCTION");
+    profiler_add(EVENT_LOOP_COMPLETION,"EVENT_LOOP_COMPLETION");
+    profiler_enable_core();
+}
+
+void profiler_enable_core()
+{
+    int x=0;
+    int core_event_count = sizeof(profiler_core_event_types)/sizeof(int);
+    while(x<=core_event_count)
+    {
+        profiler_setstate(profiler_core_event_types[x],1);
+        x++;
+    }
+}
+
+void profiler_enable_all()
+{
+    int x=0;
+    while(x<=profiler_item_count)
+    {
+        profiler_setstate(x,1);
+        x++;
+    }
+}
+
+void profiler_full_reset(profiler_item *p[])
+{
+    int x=0;
+    while(x<= profiler_item_count)
+    {
+        profiler_item_reset(p[x]);
+        x++;
+    }
+}
+
+void profiler_item_reset(profiler_item *p)
+{
+    p->state=0;
+    p->counter=0;
+    p->elapsed=0;
+}
+
+void profiler_free(profiler_item *p[], int count)
+{
+       //Free the old memory
+    int x=count;
+    for(; x > 0; x--)
+    {
+        free(p[x]->name);
+        free(p[x]);
+    }
+}
+
+ void profiler_add(int event, char *name)
+{
+    if(event >= profiler_item_count)
+    {
+        profiler_item_count = event;
+        profiler = realloc(profiler,(sizeof(profiler_item) * (++profiler_item_count)));
+        if(profiler == NULL)
+        {
+            printf("Could not allocate sufficient memory, exiting now!\n");
+            exit(0);
+        }
+
+    }
+
+    profiler[event].state = 0;
+    profiler[event].counter = 0;
+    profiler[event].elapsed = 0;
+    profiler[event].name = strdup(name);
+}
+
+void profiler_setstate(int event,int state)
+{
+     profiler[event].state = state;
+}
+
+void profiler_rename(int p, char * name)
+{
+        free(profiler[p].name);
+        profiler[p].name = strdup(name);
+}
+
+int profiler_update(int event, struct timeval start)
+{
+    static int counter;
+    struct timeval end;
+    gettimeofday(&end,NULL);
+
+    //We do this to prevent segfaulting since it could be a we end up with a sparse array
+    //It's ugly but it saves having to try and know everything that may be profiled in advance.
+    //It's only slow the first time a new event type is profiled.
+    while(event > profiler_item_count)
+    {
+        char name[20];
+        memset(name,'\0',20);
+        sprintf(name,"UNKNOWN_%d",counter++);
+        profiler_add(event,(char*)&name);
+    }
+
+    if(profiler[event].state)
+    {
+        profiler[event].elapsed+=(double)((end.tv_usec - start.tv_usec)/1000000) + ((end.tv_sec - start.tv_sec));
+        profiler[event].counter++;
+    }
+}
+
+void profiler_output(FILE* fp)
+{
+    int c;
+    for(c=0; c < profiler_item_count; c++)
+    {
+        //Only print those that are turned on.
+        if(profiler[c].state)
+        {
+            if(profiler[c].name)
+            {
+                fprintf(fp,"\tPROFILE_COUNTER_%s=%d\n",profiler[c].name,profiler[c].counter);
+                fprintf(fp,"\tPROFILE_ELAPSED_%s=%f\n",profiler[c].name,profiler[c].elapsed);
+            }
+        }
+    }
+
+}
+
+#endif EVENT_PROFILER
diff -wurpN nagios-3-clean/base/statsprofiler.c nagios-3-modified/base/statsprofiler.c
--- nagios-3-clean/base/statsprofiler.c	1969-12-31 17:00:00.000000000 -0700
+++ nagios-3-modified/base/statsprofiler.c	2009-06-17 21:34:10.000000000 -0600
@@ -0,0 +1,129 @@
+#ifdef EVENT_PROFILER
+#include "../include/config.h"
+#include "../include/common.h"
+#include "../include/nagios.h"
+#include "../include/locations.h"
+#include "../include/statsprofiler.h"
+
+extern profile_object* profiled_data;
+
+double safe_divide(double x, int y, int reverse)
+{
+
+    double ans;
+    if(x == 0 || y ==0)
+    {
+        ans = 0.0f;
+    }else{
+        if(reverse)
+        {
+            ans = y/x;
+        }else{
+            ans = x/y;
+        }
+    }
+    return ans;
+}
+
+profile_object* profiled_data_find_last_object()
+{
+    profile_object* p = profiled_data;
+    if(p)
+    {
+        while(p->next && p->next != p)
+            p = p->next;
+    }
+    return p;
+}
+
+profile_object* profile_object_create(char * name)
+{
+    profile_object* new_p =  (profile_object*) calloc(1,sizeof(profile_object));
+    profile_object* old_p = profiled_data_find_last_object();
+
+    if(!old_p)
+    {
+        profiled_data = old_p = new_p;
+    }
+
+    if(new_p != old_p)
+        old_p->next = new_p;
+
+    new_p->name = strdup(name);
+    return new_p;
+}
+
+profile_object* profile_object_find_by_name(char * name)
+{
+    profile_object* p = profiled_data;
+    char * n_name = calloc(strlen(name)+1,sizeof(char));
+    strncpy(n_name,name,strlen(name));
+
+    while(p != NULL)
+    {
+        if(strcmp(n_name,p->name)==0)
+        {
+            break;
+        }
+        p = p->next;
+    }
+
+    if(!p)
+    {
+        p = profile_object_create(n_name);
+    }
+    free(n_name);
+    return p;
+}
+
+void profile_object_update_count(char * name, int val)
+{
+    profile_object* new_p = profile_object_find_by_name(name);
+    new_p->count=val;
+}
+
+void profile_object_update_elapsed(char * name, double val)
+{
+    profile_object * new_p = profile_object_find_by_name(name);
+    new_p->elapsed=val;
+}
+
+void profile_data_print()
+{
+    int count,x;
+    char * name;
+    double elapsed;
+    double total_time;
+    profile_object *t, *p = profiled_data;
+    t=profile_object_find_by_name("EVENT_LOOP_COMPLETION");
+    total_time = t->elapsed;
+
+    while(p)
+    {
+       name = p->name;
+       count = p->count;
+       elapsed = p->elapsed;
+
+       printf("%s\t\t\t%.3f / %d / %.4f / %.4f\n",name,elapsed,count,safe_divide(elapsed,count,0),safe_divide(total_time,count,1));
+       p = p->next;
+    }
+}
+
+void profile_data_output_mrtg(char * name, char * delim)
+{
+    int t_len = strlen(name);
+    char t_name[t_len];
+    strncpy(t_name,name+strlen("COUNTER_"),t_len);
+    profile_object* p = profile_object_find_by_name(t_name);
+    profile_object* t = profile_object_find_by_name("EVENT_LOOP_COMPLETION");
+
+    if(strstr(name,"ELAPSED"))
+        printf("%.3f%s",p->elapsed,delim);
+
+    if(strstr(name,"COUNTER"))
+        printf("%d%s",p->count,delim);
+
+    if(strstr(name,"EVENTPS"))
+        printf("%.4f%s",safe_divide(t->elapsed,p->count,1),delim);
+}
+#endif
diff -wurpN nagios-3-clean/include/profiler.h nagios-3-modified/include/profiler.h
--- nagios-3-clean/include/profiler.h	1969-12-31 17:00:00.000000000 -0700
+++ nagios-3-modified/include/profiler.h	2009-06-17 12:50:26.000000000 -0600
@@ -0,0 +1,74 @@
+
+/*****************************************************************************
+ *
+ * PROFILER.H - Event Profiler For Nagios
+ *
+ * Program: Nagios
+ * Version: 2.12
+ * License: GPL
+ * Copyright: (c) 2009 Intellectual Reserve Inc.
+ * Author:  Steven D. Morrey (nagios-devel@lists.sourceforge.net
+ *
+ * First Written:   06-09-2009 (start of development)
+ * Last Modified:   06-09-2009
+ *
+ * Description:
+ *
+ * Nagios is a network monitoring tool that will check hosts and services
+ * that you specify.  This utility adds the ability to profile the events
+ * occuring within the application itself
+ *
+ * License:
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *****************************************************************************/
+#ifndef __PROFILER__HEADER__INCLUDED__
+#define __PROFILER__HEADER__INCLUDED__
+
+#ifdef EVENT_PROFILER
+
+#define EVENT_LOOP_EMPTY_LIST                   100
+#define EVENT_LOOP_EVENT_LIST_HIGH_EXECUTED     101
+#define EVENT_LOOP_FAIL_NO_SERVICE_CHECKS       102
+#define EVENT_LOOP_FAIL_MAX_CHECKS              103
+#define EVENT_LOOP_FAIL_PARALLEL                104
+#define EVENT_LOOP_FAIL_NO_HOST_CHECKS          105
+#define EVENT_LOOP_EXECUTED_EVENT               106
+#define EVENT_LOOP_NO_EXECUTION                 107
+#define EVENT_LOOP_IDLED                        108
+#define EVENT_LOOP_COMPLETION                   109
+
+
+typedef struct profiler_item{
+    int   state;
+    int    counter;
+    double elapsed;
+    char * name;
+}profiler_item;
+
+extern profiler_item * profiler;
+
+void profiler_init();
+void profiler_enable_core();
+void profiler_enable_all();
+void profiler_full_reset(profiler_item *p[]);
+void profiler_item_reset(profiler_item *p);
+void profiler_add(int event, char *name);
+void profiler_setstate(int event,int state);
+void profiler_rename(int p, char * name);
+int profiler_update(int event, struct timeval start);
+void profiler_output(FILE* fp);
+#endif
+#endif
diff -wurpN nagios-3-clean/include/statsprofiler.h nagios-3-modified/include/statsprofiler.h
--- nagios-3-clean/include/statsprofiler.h	1969-12-31 17:00:00.000000000 -0700
+++ nagios-3-modified/include/statsprofiler.h	2009-06-17 21:31:29.000000000 -0600
@@ -0,0 +1,21 @@
+#ifndef __STATS_PROFILER_INCLUDED__
+#define __STATS_PROFILER_INCLUDED__
+
+typedef struct profile_object{
+
+    char* name;
+    int count;
+    double elapsed;
+    struct profile_object* next;
+
+}profile_object;
+
+profile_object* profiled_data_find_last_object();
+profile_object* profile_object_create(char * name);
+profile_object* profile_object_find_by_name(char * name);
+double safe_divide(double x, int y, int reverse);
+void profile_object_update_count(char * name, int val);
+void profile_object_update_elapsed(char * name, double val);
+void profile_data_print();
+void profile_data_output_mrtg(char * name,char * delim);
+#endif
diff -wurpN nagios-3-clean/xdata/xsddefault.c nagios-3-modified/xdata/xsddefault.c
--- nagios-3-clean/xdata/xsddefault.c	2009-05-15 07:16:57.000000000 -0600
+++ nagios-3-modified/xdata/xsddefault.c	2009-06-17 21:09:09.000000000 -0600
@@ -34,6 +34,10 @@
 #include "../include/macros.h"
 #include "../include/skiplist.h"
 
+#ifdef EVENT_PROFILER
+#include "../include/profiler.h"
+#endif
+
 #ifdef NSCORE
 #include "../include/nagios.h"
 #endif
@@ -459,6 +463,9 @@ int xsddefault_save_status_data(void){
 
 	fprintf(fp,"\tparallel_host_check_stats=%d,%d,%d\n",check_statistics[PARALLEL_HOST_CHECK_STATS].minute_stats[0],check_statistics[PARALLEL_HOST_CHECK_STATS].minute_stats[1],check_statistics[PARALLEL_HOST_CHECK_STATS].minute_stats[2]);
 	fprintf(fp,"\tserial_host_check_stats=%d,%d,%d\n",check_statistics[SERIAL_HOST_CHECK_STATS].minute_stats[0],check_statistics[SERIAL_HOST_CHECK_STATS].minute_stats[1],check_statistics[SERIAL_HOST_CHECK_STATS].minute_stats[2]);
+#ifdef EVENT_PROFILER
+    profiler_output(fp);
+#endif
 	fprintf(fp,"\t}\n\n");
 
 
